@@ -340,4 +340,19 @@ typedef unsigned char uchar;
 #define SCANF_SYNTAX(strindex)
 #endif
 
+// providing "std::make_unique" for GCC 4.8.x (only 4.8.x)
+#if __GNUC__ && __cplusplus < 201402L && __cpp_generic_lambdas < 201304
+namespace std {
+template<class T> struct _Unique_if { typedef unique_ptr<T> _Single_object; };
+template<class T> struct _Unique_if<T[]> { typedef unique_ptr<T[]> _Unknown_bound; };
+template<class T, class... Args> typename _Unique_if<T>::_Single_object make_unique(Args&&... args) {
+	return unique_ptr<T>(new T(std::forward<Args>(args)...));
+}
+template<class T> typename _Unique_if<T>::_Unknown_bound make_unique(size_t n) {
+	typedef typename remove_extent<T>::type U;
+	return unique_ptr<T>(new U[n]());
+}
+}
+#endif
+
 #endif /* NZBGET_H */
