@@ -1,7 +1,7 @@
 /*
- *  This file is part of nzbget
+ *  This file is part of nzbget. See <http://nzbget.net>.
  *
- *  Copyright (C) 2007-2015 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ *  Copyright (C) 2007-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,28 +14,24 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- *
- * $Revision$
- * $Date$
- *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
 #ifndef PARPARSER_H
 #define PARPARSER_H
 
-#include <deque>
+#include "NString.h"
+#include "Container.h"
 
 class ParParser
 {
 public:
-	typedef std::deque<char*>		ParFileList;
+	typedef std::vector<CString> ParFileList;
 
-	static bool			FindMainPars(const char* szPath, ParFileList* pFileList);
-	static bool			ParseParFilename(const char* szParFilename, int* iBaseNameLen, int* iBlocks);
-	static bool			SameParCollection(const char* szFilename1, const char* szFilename2);
+	static bool FindMainPars(const char* path, ParFileList* fileList);
+	static bool ParseParFilename(const char* parFilename, int* baseNameLen, int* blocks);
+	static bool SameParCollection(const char* filename1, const char* filename2);
 };
 
 #endif
