@@ -30,6 +30,16 @@ CString FileSystem::GetLastErrorMessage()
 {
 	BString<1024> msg;
 	strerror_r(errno, msg, msg.Capacity());
+
+#ifdef WIN32
+	if (!errno)
+	{
+		FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
+			nullptr, GetLastError(), MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
+			msg, 1024, nullptr);
+	}
+#endif
+
 	return *msg;
 }
 
@@ -105,6 +115,7 @@ bool FileSystem::ForceDirectories(const char* path, CString& errmsg)
 		}
 	}
 
+	errmsg.Format("path %s does not exist and could not be created", *normPath);
 	return false;
 }
 #else
@@ -249,6 +260,7 @@ bool FileSystem::AllocateFile(const char* filename, int64 size, bool sparse, CSt
 	HANDLE hFile = CreateFileW(UtfPathToWidePath(filename), GENERIC_WRITE, FILE_SHARE_READ, 0, CREATE_NEW, 0, nullptr);
 	if (hFile == INVALID_HANDLE_VALUE)
 	{
+		errno = 0; // wanting error message from WinAPI instead of C-lib 
 		errmsg = GetLastErrorMessage();
 		return false;
 	}
@@ -526,17 +538,21 @@ bool FileSystem::DirectoryExists(const char* dirFilename)
 {
 #ifdef WIN32
 	WIN32_FIND_DATAW findData;
-	// extra "\*" needed for network shares
 	HANDLE handle = FindFirstFileW(UtfPathToWidePath(
 		BString<1024>(dirFilename && dirFilename[strlen(dirFilename) - 1] == PATH_SEPARATOR ? "%s*" : "%s\\*", dirFilename)),
 		&findData);
 	if (handle != INVALID_HANDLE_VALUE)
 	{
 		bool exists = ((findData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) != 0) ||
-			(strlen(dirFilename) == 3 && dirFilename[1] == ':');
+			(dirFilename[0] != '\0' && dirFilename[1] == ':' && (dirFilename[2] == '\0' || dirFilename[3] == '\0'));
 		FindClose(handle);
 		return exists;
 	}
+	if (GetLastError() == ERROR_FILE_NOT_FOUND)
+	{
+		// path exists but doesn't have any file/directory entries - possible only for root paths (e. g. "C:\")
+		return true;
+	}
 	return false;
 #else
 	struct stat buffer;
@@ -841,10 +857,8 @@ bool FileSystem::FlushFileBuffers(int fileDescriptor, CString& errmsg)
 	BOOL ok = ::FlushFileBuffers((HANDLE)_get_osfhandle(fileDescriptor));
 	if (!ok)
 	{
-		errmsg.Reserve(1024 - 1);
-		FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
-			nullptr, GetLastError(), MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
-			errmsg, 1024, nullptr);
+		errno = 0; // wanting error message from WinAPI instead of C-lib 
+		errmsg = GetLastErrorMessage();
 	}
 	return ok;
 #else
