@@ -1,7 +1,7 @@
 /*
- *  This file is part of nzbget
+ *  This file is part of nzbget. See <http://nzbget.net>.
  *
- *  Copyright (C) 2015 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ *  Copyright (C) 2015-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,35 +14,28 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- *
- * $Revision$
- * $Date$
- *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
 #ifndef SERVICE_H
 #define SERVICE_H
 
-#include <vector>
-
 #include "Thread.h"
 
 class Service
 {
-private:
-	int					m_iLastTick;
+public:
+	Service();
 
 protected:
-	virtual int			ServiceInterval() = 0;
-	virtual void		ServiceWork() = 0;
+	virtual int ServiceInterval() = 0;
+	virtual void ServiceWork() = 0;
+
+private:
+	int m_lastTick = 0;
 
 	friend class ServiceCoordinator;
-
-public:
-						Service();
 };
 
 class ServiceCoordinator : public Thread
@@ -50,19 +43,18 @@ class ServiceCoordinator : public Thread
 public:
 	typedef std::vector<Service*> ServiceList;
 
-private:
-	ServiceList	m_Services;
+	ServiceCoordinator();
+	virtual ~ServiceCoordinator();
+	virtual void Run();
 
-	void				RegisterService(Service* pService);
+private:
+	ServiceList m_services;
+
+	void RegisterService(Service* service);
 
 	friend class Service;
-
-public:
-						ServiceCoordinator();
-	virtual				~ServiceCoordinator();
-	virtual void		Run();
 };
 
-extern ServiceCoordinator* g_pServiceCoordinator;
+extern ServiceCoordinator* g_ServiceCoordinator;
 
 #endif
