@@ -17,6 +17,7 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
+#include "nzbget.h"
 #include "par2cmdline.h"
 
 #ifdef _MSC_VER
@@ -27,6 +28,9 @@ static char THIS_FILE[]=__FILE__;
 #endif
 #endif
 
+namespace Par2
+{
+
 Par2Repairer::Par2Repairer(void)
 {
   firstpacket = true;
@@ -2552,3 +2556,5 @@ bool Par2Repairer::DeleteIncompleteTargetFiles(void)
 
   return true;
 }
+
+} // end namespace Par2
