@@ -1,7 +1,7 @@
 /*
- * This file is part of nzbget
+ * This file is part of nzbget. See <http://nzbget.net>.
  *
- * Copyright (C) 2012-2015 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * Copyright (C) 2012-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,12 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- *
- * $Revision: 1254 $
- * $Date: 2015-04-11 07:32:49 -0400 (Sat, 11 Apr 2015) $
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -59,6 +54,7 @@ var History = (new function($)
 
 		var recordsPerPage = UISettings.read('HistoryRecordsPerPage', 10);
 		$HistoryRecordsPerPage.val(recordsPerPage);
+		$('#HistoryTable_filter').val('');
 
 		$HistoryTable.fasttable(
 			{
@@ -67,7 +63,6 @@ var History = (new function($)
 				pagerContainer: $('#HistoryTable_pager'),
 				infoContainer: $('#HistoryTable_info'),
 				headerCheck: $('#HistoryTable > thead > tr:first-child'),
-				filterCaseSensitive: false,
 				pageSize: recordsPerPage,
 				maxPages: UISettings.miniTheme ? 1 : 5,
 				pageDots: !UISettings.miniTheme,
@@ -125,7 +120,8 @@ var History = (new function($)
 		for (var j=0, jl=history.length; j < jl; j++)
 		{
 			var hist = history[j];
-			if (hist.Status === 'DELETED/MANUAL')
+			if (hist.Status === 'DELETED/MANUAL' || hist.Status === 'DELETED/GOOD' ||
+				hist.Status === 'DELETED/SUCCESS' || hist.Status === 'DELETED/COPY')
 			{
 				hist.FilterKind = 'DELETED';
 			}
@@ -144,6 +140,8 @@ var History = (new function($)
 		}
 	}
 
+	var SEARCH_FIELDS = ['name', 'status', 'priority', 'category', 'age', 'size', 'time'];
+
 	this.redraw = function()
 	{
 		var data = [];
@@ -153,39 +151,26 @@ var History = (new function($)
 			var hist = history[i];
 
 			var kind = hist.Kind;
-			var statustext = HistoryUI.buildStatusText(hist);
-			var size = kind === 'URL' ? '' : Util.formatSizeMB(hist.FileSizeMB);
-			var time = Util.formatDateTime(hist.HistoryTime + UISettings.timeZoneCorrection*60*60);
-			var dupe = DownloadsUI.buildDupeText(hist.DupeKey, hist.DupeScore, hist.DupeMode);
-			var category = '';
+			hist.status = HistoryUI.buildStatusText(hist);
+			hist.name = hist.Name;
+			hist.size = kind === 'URL' ? '' : Util.formatSizeMB(hist.FileSizeMB);
+			hist.sizemb = hist.FileSizeMB;
+			hist.sizegb = hist.FileSizeMB / 1024;
+			hist.time = Util.formatDateTime(hist.HistoryTime + UISettings.timeZoneCorrection*60*60);
+			hist.category = kind !== 'DUP' ? hist.Category : '';
+			hist.dupe = DownloadsUI.buildDupeText(hist.DupeKey, hist.DupeScore, hist.DupeMode);
+			var age_sec = kind === 'NZB' ? new Date().getTime() / 1000 - (hist.MinPostTime + UISettings.timeZoneCorrection*60*60) : 0;
+			hist.age = kind === 'NZB' ? Util.formatAge(hist.MinPostTime + UISettings.timeZoneCorrection*60*60) : '';
+			hist.agem = Util.round0(age_sec / 60);
+			hist.ageh = Util.round0(age_sec / (60*60));
+			hist.aged = Util.round0(age_sec / (60*60*24));
 
-			var textname = hist.Name;
-			var age = '';
-			if (kind === 'NZB')
-			{
-				age = Util.formatAge(hist.MinPostTime + UISettings.timeZoneCorrection*60*60);
-				textname += ' URL';
-			}
-			else if (kind === 'URL')
-			{
-				textname += ' URL';
-			}
-			else if (kind === 'DUP')
-			{
-				textname += ' hidden';
-			}
-
-			if (kind !== 'DUP')
-			{
-				category = hist.Category;
-			}
+			hist._search = SEARCH_FIELDS;
 
 			var item =
 			{
 				id: hist.ID,
-				hist: hist,
-				data: { time: time, age: age, size: size },
-				search: statustext + ' ' + time + ' ' + textname + ' ' + dupe + ' ' + category + ' ' +  age + ' ' + size
+				data: hist,
 			};
 
 			data.push(item);
@@ -199,7 +184,7 @@ var History = (new function($)
 
 	function fillFieldsCallback(item)
 	{
-		var hist = item.hist;
+		var hist = item.data;
 
 		var status = HistoryUI.buildStatus(hist);
 
@@ -272,9 +257,10 @@ var History = (new function($)
 	this.actionClick = function(action)
 	{
 		var checkedRows = $HistoryTable.fasttable('checkedRows');
-		if (checkedRows.length == 0)
+		var checkedCount = $HistoryTable.fasttable('checkedCount');
+		if (checkedCount === 0)
 		{
-			Notification.show('#Notif_History_Select');
+			PopupNotification.show('#Notif_History_Select');
 			return;
 		}
 
@@ -285,12 +271,13 @@ var History = (new function($)
 		for (var i = 0; i < history.length; i++)
 		{
 			var hist = history[i];
-			if (checkedRows.indexOf(hist.ID) > -1)
+			if (checkedRows[hist.ID])
 			{
 				hasNzb |= hist.Kind === 'NZB';
 				hasUrl |= hist.Kind === 'URL';
 				hasDup |= hist.Kind === 'DUP';
-				hasFailed |= hist.ParStatus === 'FAILURE' || hist.UnpackStatus === 'FAILURE';
+				hasFailed |= hist.ParStatus === 'FAILURE' || hist.UnpackStatus === 'FAILURE' ||
+					hist.DeleteStatus != 'NONE';
 			}
 		}
 
@@ -298,13 +285,13 @@ var History = (new function($)
 		{
 			case 'DELETE':
 				notification = '#Notif_History_Deleted';
-				HistoryUI.deleteConfirm(historyAction, hasNzb, hasDup, hasFailed, true);
+				HistoryUI.deleteConfirm(historyAction, hasNzb, hasDup, hasFailed, true, checkedCount);
 				break;
 
 			case 'REPROCESS':
 				if (hasUrl || hasDup)
 				{
-					Notification.show('#Notif_History_CantReprocess');
+					PopupNotification.show('#Notif_History_CantReprocess');
 					return;
 				}
 				notification = '#Notif_History_Reprocess';
@@ -314,13 +301,14 @@ var History = (new function($)
 			case 'REDOWNLOAD':
 				if (hasDup)
 				{
-					Notification.show('#Notif_History_CantRedownload');
+					PopupNotification.show('#Notif_History_CantRedownload');
 					return;
 				}
 				notification = '#Notif_History_Returned';
 				ConfirmDialog.showModal('HistoryEditRedownloadConfirmDialog',
 					function () { historyAction('HistoryRedownload') },
-					function () { HistoryUI.confirmMulti(checkedRows.length > 1); });
+					function () { HistoryUI.confirmMulti(checkedCount > 1); },
+					checkedCount);
 				break;
 
 			case 'MARKSUCCESS':
@@ -328,7 +316,7 @@ var History = (new function($)
 			case 'MARKBAD':
 				if (hasUrl)
 				{
-					Notification.show('#Notif_History_CantMark');
+					PopupNotification.show('#Notif_History_CantMark');
 					return;
 				}
 				notification = '#Notif_History_Marked';
@@ -342,8 +330,9 @@ var History = (new function($)
 					},
 					function (_dialog) // init
 					{
-						HistoryUI.confirmMulti(checkedRows.length > 1);
-					}
+						HistoryUI.confirmMulti(checkedCount > 1);
+					},
+					checkedCount
 				);
 				break;
 		}
@@ -352,8 +341,15 @@ var History = (new function($)
 	function historyAction(command)
 	{
 		Refresher.pause();
-		var IDs = $HistoryTable.fasttable('checkedRows');
-		RPC.call('editqueue', [command, 0, '', [IDs]], function()
+
+		var ids = [];
+		var checkedRows = $HistoryTable.fasttable('checkedRows');
+		for (var id in checkedRows)
+		{
+			ids.push(parseInt(id));
+		}		
+		
+		RPC.call('editqueue', [command, 0, '', ids], function()
 		{
 			editCompleted();
 		});
@@ -364,7 +360,7 @@ var History = (new function($)
 		Refresher.update();
 		if (notification)
 		{
-			Notification.show(notification);
+			PopupNotification.show(notification);
 			notification = null;
 		}
 	}
@@ -399,7 +395,7 @@ var History = (new function($)
 
 	function filterCallback(item)
 	{
-		return !activeTab || curFilter === 'ALL' || item.hist.FilterKind === curFilter;
+		return !activeTab || curFilter === 'ALL' || item.data.FilterKind === curFilter;
 	}
 
 	function initFilterButtons()
@@ -418,7 +414,7 @@ var History = (new function($)
 
 		for (var i=0; i < data.length; i++)
 		{
-			var hist = data[i].hist;
+			var hist = data[i].data;
 			switch (hist.FilterKind)
 			{
 				case 'SUCCESS': countSuccess++; break;
@@ -499,10 +495,9 @@ var HistoryUI = (new function($)
 		return '<span class="label label-status ' + badgeClass + '">' + statusText + '</span>';
 	}
 	
-	this.deleteConfirm = function(actionCallback, hasNzb, hasDup, hasFailed, multi)
+	this.deleteConfirm = function(actionCallback, hasNzb, hasDup, hasFailed, multi, selCount)
 	{
 		var dupeCheck = Options.option('DupeCheck') === 'yes';
-		var cleanupDisk = Options.option('DeleteCleanupDisk') === 'yes';
 		var dialog = null;
 
 		function init(_dialog)
@@ -512,8 +507,7 @@ var HistoryUI = (new function($)
 			$('#HistoryDeleteConfirmDialog_Hide', dialog).prop('checked', true);
 			Util.show($('#HistoryDeleteConfirmDialog_Options', dialog), hasNzb && dupeCheck);
 			Util.show($('#HistoryDeleteConfirmDialog_Simple', dialog), !(hasNzb && dupeCheck));
-			Util.show($('#HistoryDeleteConfirmDialog_DeleteWillCleanup', dialog), hasNzb && hasFailed && cleanupDisk);
-			Util.show($('#HistoryDeleteConfirmDialog_DeleteCanCleanup', dialog), hasNzb && hasFailed && !cleanupDisk);
+			Util.show($('#HistoryDeleteConfirmDialog_DeleteWillCleanup', dialog), hasNzb && hasFailed);
 			Util.show($('#HistoryDeleteConfirmDialog_DeleteNoCleanup', dialog), !(hasNzb && hasFailed));
 			Util.show($('#HistoryDeleteConfirmDialog_DupAlert', dialog), !hasNzb && dupeCheck && hasDup);
 			Util.show('#ConfirmDialog_Help', hasNzb && dupeCheck);
@@ -526,7 +520,7 @@ var HistoryUI = (new function($)
 			actionCallback(command);
 		}
 
-		ConfirmDialog.showModal('HistoryDeleteConfirmDialog', action, init);
+		ConfirmDialog.showModal('HistoryDeleteConfirmDialog', action, init, selCount);
 	}
 	
 	this.confirmMulti = function(multi)
