@@ -1,7 +1,7 @@
 /*
- * This file is part of nzbget
+ * This file is part of nzbget. See <http://nzbget.net>.
  *
- * Copyright (C) 2012-2014 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * Copyright (C) 2012-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,19 +14,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- *
- * $Revision: 1057 $
- * $Date: 2014-07-18 18:48:35 -0400 (Fri, 18 Jul 2014) $
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * In this module:
  *   1) Status Infos on main page (speed, time, paused state etc.);
  *   2) Statistics and Status dialog;
- *   3) Limit dialog (speed and active news servers).
+ *   3) Limit dialog (speed and active news servers);
+ *   4) Filter menu.
  */
 
 /*** STATUS INFOS ON MAIN PAGE AND STATISTICS DIALOG ****************************************/
@@ -64,6 +60,7 @@ var Status = (new function($)
 	var lastAnimState = 0;
 	var playInitialized = false;
 	var modalShown = false;
+	var titleGen = [];
 
 	this.init = function()
 	{
@@ -100,6 +97,8 @@ var Status = (new function($)
 		$('body > .modal').on('hide', modalHide);
 
 		StatDialog.init();
+		FilterMenu.init();
+		initTitle();
 	}
 
 	this.update = function()
@@ -181,9 +180,13 @@ var Status = (new function($)
 
 		$StatusSpeedIcon.toggleClass('icon-plane', !limit);
 		$StatusSpeedIcon.toggleClass('icon-truck', limit);
-		$StatusTime.toggleClass('scheduled-resume', status.ServerStandBy && status.ResumeTime > 0);
-		$StatusTimeIcon.toggleClass('icon-time', !(status.ServerStandBy && status.ResumeTime > 0));
-		$StatusTimeIcon.toggleClass('icon-time-orange', status.ServerStandBy && status.ResumeTime > 0);
+
+		var statWarning = (status.ServerStandBy && status.ResumeTime > 0) || status.QuotaReached;
+		$StatusTime.toggleClass('orange', statWarning);
+		$StatusTimeIcon.toggleClass('icon-time', !statWarning);
+		$StatusTimeIcon.toggleClass('icon-time-orange', statWarning);
+		
+		updateTitle();
 	}
 
 	function updatePlayButton()
@@ -205,7 +208,7 @@ var Status = (new function($)
 			showBtn.fadeIn(500);
 			if (!Play && !status.ServerStandBy)
 			{
-				Notification.show('#Notif_Downloads_Pausing');
+				PopupNotification.show('#Notif_Downloads_Pausing');
 			}
 		}
 		else
@@ -229,10 +232,10 @@ var Status = (new function($)
 	function updatePlayAnim()
 	{
 		// Animate if either any downloads or post-processing is in progress
-		var Anim = (!status.ServerStandBy || status.FeedActive ||
+		var Anim = (!status.ServerStandBy || status.FeedActive || status.QueueScriptCount > 0 ||
 			(status.PostJobCount > 0 && !status.PostPaused) ||
 			(status.UrlCount > 0 && (!status.DownloadPaused || Options.option('UrlForce') === 'yes'))) &&
-			(UISettings.refreshInterval !== 0) && !UISettings.connectionError;
+			(UISettings.refreshInterval !== 0) && !UISettings.connectionError && UISettings.activityAnimation;
 		if (Anim === lastAnimState)
 		{
 			return;
@@ -240,7 +243,7 @@ var Status = (new function($)
 
 		lastAnimState = Anim;
 
-		if (UISettings.activityAnimation && !modalShown)
+		if (!modalShown)
 		{
 			if (Anim)
 			{
@@ -255,7 +258,7 @@ var Status = (new function($)
 
 	this.playClick = function()
 	{
-		//Notification.show('#Notif_Play');
+		//PopupNotification.show('#Notif_Play');
 
 		if (lastPlayState)
 		{
@@ -341,7 +344,6 @@ var Status = (new function($)
 		modalShown = false;
 	}
 
-
 	this.serverName = function(server)
 	{
 		var name = Options.option('Server' + server.ID + '.Name');
@@ -354,6 +356,74 @@ var Status = (new function($)
 		return name;
 	}
 
+	function initTitle()
+	{
+		function format(pattern, paramFunc)
+		{
+			if (UISettings.connectionError)
+			{
+				var value = '?';
+				var isEmpty = false;
+			}
+			else
+			{
+				var param = paramFunc();
+				var value = param[0];
+				var isEmpty = param[1];
+			}
+
+			if (isEmpty && pattern != '%VAR%')
+			{
+				return '';
+			}
+
+			switch (pattern)
+			{
+				case '%VAR%': return value;
+				case '%VAR-%': return '' + value + ' - ';
+				case '%(VAR)%': return '(' + value + ')';
+				case '%(VAR-)%': return '(' + value + ') - ';
+				case '%[VAR]%': return '[' + value + ']';
+				case '%[VAR-]%': return '[' + value + '] - ';
+			}
+			
+			return Downloads.groups.length > 0 ? '' + Downloads.groups.length + ' - ' : '';
+		};
+		
+		function fill(varname, paramFunc)
+		{
+			titleGen['%' + varname + '%'] = function() { return format('%VAR%', paramFunc); };
+			titleGen['%' + varname + '-%'] = function() { return format('%VAR-%', paramFunc); };
+			titleGen['%(' + varname + ')%'] = function() { return format('%(VAR)%', paramFunc); };
+			titleGen['%(' + varname + '-)%'] = function() { return format('%(VAR-)%', paramFunc); };
+			titleGen['%[' + varname + ']%'] = function() { return format('%[VAR]%', paramFunc); };
+			titleGen['%[' + varname + '-]%'] = function() { return format('%[VAR-]%', paramFunc); };
+		}
+
+		fill('COUNT', function() { return [Downloads.groups.length, Downloads.groups.length == 0]; });
+		fill('SPEED', function() { return [$StatusSpeed.text(), status.ServerStandBy]; });
+		fill('TIME', function() { return [$StatusTime.text(), status.ServerStandBy]; });
+		fill('PAUSE', function() { return ['||', !status.DownloadPaused]; });
+	}
+
+	function updateTitle()
+	{
+		var title = UISettings.windowTitle;
+
+		for (var name in titleGen)
+		{
+			if (title.indexOf(name) > -1)
+			{
+				var value = titleGen[name]();
+				title = title.replace(name, value);
+			}
+		}
+
+		title = title.trim();
+
+		window.document.title = title;
+	}
+	this.updateTitle = updateTitle;
 }(jQuery));
 
 
@@ -375,6 +445,7 @@ var StatDialog = (new function($)
 	var $StatDialog_DataCurrentSpeed;
 	var $StatDialog_DataSpeedLimit;
 	var $StatDialog_ArticleCache;
+	var $StatDialog_QueueScripts;
 	var $StatDialog_ChartBlock;
 	var $StatDialog_Server;
 	var $StatRangeDialog;
@@ -421,7 +492,8 @@ var StatDialog = (new function($)
 		$StatDialog_DataAverageSpeed = $('#StatDialog_DataAverageSpeed');
 		$StatDialog_DataCurrentSpeed = $('#StatDialog_DataCurrentSpeed');
 		$StatDialog_DataSpeedLimit = $('#StatDialog_DataSpeedLimit');
-		$StatDialog_ArticleCache = $('#StatDialog_ArticleCache');		
+		$StatDialog_ArticleCache = $('#StatDialog_ArticleCache');
+		$StatDialog_QueueScripts = $('#StatDialog_QueueScripts');
 		$StatDialog_ChartBlock = $('#StatDialog_ChartBlock');
 		$StatDialog_Server = $('#StatDialog_Server');
 		$StatRangeDialog = $('#StatRangeDialog');
@@ -498,7 +570,14 @@ var StatDialog = (new function($)
 		$('#StatDialog_BackSpace').show();
 		$('#StatDialog_Title').text('Statistics and Status');
 		Util.show('#StatDialog_ArticleCache_Row', Options.option('ArticleCache') !== '0');
+		Util.show('#StatDialog_QueueScripts_Row', Status.status.QueueScriptCount > 0);
 		$StatDialog.removeClass('modal-large').addClass('modal-mini');
+
+		if (Options.option('QuotaStartDay') != '1')
+		{
+			$('#StatDialog_MonthTitle').text('Billing month:');
+		}
+
 		monthListInitialized = false;
 		updateServerList();
 		lastTab = null;
@@ -546,6 +625,7 @@ var StatDialog = (new function($)
 		$StatDialog_DataCurrentSpeed.html(Util.formatSpeed(status.DownloadRate));
 		$StatDialog_DataSpeedLimit.html(Util.formatSpeed(status.DownloadLimit));
 		$StatDialog_ArticleCache.html(Util.formatSizeMB(status.ArticleCacheMB, status.ArticleCacheLo));
+		$StatDialog_QueueScripts.html(status.QueueScriptCount);
 
 		var content = '';
 		content += '<tr><td>Download</td><td class="text-right">' +
@@ -568,6 +648,11 @@ var StatDialog = (new function($)
 			'<span class="label label-status label-success">active</span>')) +
 			'</td></tr>';
 
+		if (status.QuotaReached)
+		{
+			content += '<tr><td>Download quota</td><td class="text-right"><span class="label label-status label-warning">reached</span></td></tr>';
+		}
+
 		if (status.ResumeTime > 0)
 		{
 			content += '<tr><td>Autoresume</td><td class="text-right">' + Util.formatTimeHMS(status.ResumeTime - status.ServerTime) + '<i class="icon-empty"/></td></tr>';
@@ -1145,47 +1230,11 @@ var StatDialog = (new function($)
 
 	function updateCounters()
 	{
-		if (servervolumes[curServer].DaySlot > -1)
-		{
-			var bytes = servervolumes[curServer].BytesPerDays[servervolumes[curServer].DaySlot];
-			$StatDialog_TodaySize.html(Util.formatSizeMB(bytes.SizeMB, bytes.SizeLo));
-		}
-
+		$StatDialog_TodaySize.html(Util.formatSizeMB(Status.status.DaySizeMB, Status.status.DaySizeLo));
+		$StatDialog_MonthSize.html(Util.formatSizeMB(Status.status.MonthSizeMB, Status.status.MonthSizeLo));
 		$StatDialog_AllTimeSize.html(Util.formatSizeMB(servervolumes[curServer].TotalSizeMB, servervolumes[curServer].TotalSizeLo));
 		$StatDialog_CustomSize.html(Util.formatSizeMB(servervolumes[curServer].CustomSizeMB, servervolumes[curServer].CustomSizeLo));
 		$StatDialog_Custom.attr('title', 'reset on ' + Util.formatDateTime(servervolumes[curServer].CustomTime));
-
-		// calculate volume for current month
-		
-		var sizeMB = 0;
-		var sizeLo = 0;
-
-		if (clockOK)
-		{
-			var firstDay = servervolumes[0].FirstDay;
-			var monStart = dayToDate(firstDay + servervolumes[0].DaySlot);
-			monStart.setDate(1);
-			var monEnd = new Date(monStart.getFullYear(), monStart.getMonth() + 1);
-			monEnd.setDate(0);
-			
-			monStart = dateToDay(monStart);
-			monEnd = dateToDay(monEnd);
-			var monStartIndex = monStart - firstDay;
-			var monEndIndex = monEnd - firstDay;
-			var slotDelta = servervolumes[0].FirstDay - servervolumes[curServer].FirstDay;
-			for (var i = monStartIndex; i <= monEndIndex; i++)
-			{
-				var slot = i + slotDelta;
-				var bytes = servervolumes[curServer].BytesPerDays[slot];
-				if (bytes)
-				{
-					sizeMB += bytes.SizeMB;
-					sizeLo += bytes.SizeLo;
-				}
-			}
-		}
-
-		$StatDialog_MonthSize.html(Util.formatSizeMB(sizeMB, sizeLo));
 	}
 
 	function chooseMonth()
@@ -1223,7 +1272,7 @@ var StatDialog = (new function($)
 			var year = parseInt(period);
 			if (year < 2013 || year > 2050)
 			{
-				Notification.show('#Notif_StatRangeError');
+				PopupNotification.show('#Notif_StatRangeError');
 				return;
 			}
 			period = '' + year;
@@ -1234,7 +1283,7 @@ var StatDialog = (new function($)
 			var year = parseInt(period.substring(0, 4));
 			if (year < 2013 || year > 2050 || month < 1 || month > 12)
 			{
-				Notification.show('#Notif_StatRangeError');
+				PopupNotification.show('#Notif_StatRangeError');
 				return;
 			}
 			period = year + '-' + (month-1);
@@ -1255,7 +1304,7 @@ var StatDialog = (new function($)
 	{
 		RPC.call('resetservervolume', [curServer === 0 ? -1 : curServer, 'CUSTOM'], function()
 		{
-			Notification.show('#Notif_StatReset');
+			PopupNotification.show('#Notif_StatReset');
 			Refresher.update();
 		});
 	}
@@ -1312,9 +1361,20 @@ var LimitDialog = (new function($)
 		});
 	}
 
-	this.showModal = function()
+	this.clicked = function(e)
+	{
+		if (e.metaKey || e.ctrlKey)
+		{
+			toggleLimit();
+		}
+		else
+		{
+			showModal();
+		}
+	}
+
+	function showModal()
 	{
-		changed = false;
 		var rate = Util.round0(Status.status.DownloadLimit / 1024);
 		$LimitDialog_SpeedInput.val(rate > 0 ? rate : '');
 		updateTable();
@@ -1333,7 +1393,6 @@ var LimitDialog = (new function($)
 			{
 				id: server.ID,
 				fields: fields,
-				search: ''
 			};
 			data.push(item);
 
@@ -1360,6 +1419,41 @@ var LimitDialog = (new function($)
 			}
 		}
 
+		var checkedRows = $ServerTable.fasttable('checkedRows');
+		var servers = [];
+
+		for (var i=0; i < Status.status.NewsServers.length; i++)
+		{
+			var server = Status.status.NewsServers[i];
+			var selected = checkedRows[server.ID] !== undefined;
+			if (server.Active != selected)
+			{
+				servers.push([server.ID, selected]);
+			}
+		}
+
+		saveLimit(rate, servers);
+	}
+
+	function saveLimit(rate, servers)
+	{
+		function saveServers()
+		{
+			if (servers.length > 0)
+			{
+				changed = true;
+				RPC.call('editserver', servers, function()
+				{
+					completed();
+				});
+			}
+			else
+			{
+				completed();
+			}
+		}
+
+		changed = false;
 		var oldRate = Util.round0(Status.status.DownloadLimit / 1024);
 
 		if (rate != oldRate)
@@ -1376,42 +1470,185 @@ var LimitDialog = (new function($)
 		}
 	}
 
-	function saveServers()
-	{
-		var checkedRows = $ServerTable.fasttable('checkedRows');
-		var command = [];
-
-		for (var i=0; i < Status.status.NewsServers.length; i++)
-		{
-			var server = Status.status.NewsServers[i];
-			var selected = checkedRows.indexOf(server.ID) > -1;
-			if (server.Active != selected)
-			{
-				command.push([server.ID, selected]);
-				changed = true;
-			}
-		}
-
-		if (command.length > 0)
-		{
-			RPC.call('editserver', command, function()
-			{
-				completed();
-			});
-		}
-		else
-		{
-			completed();
-		}
-	}
-
 	function completed()
 	{
 		$LimitDialog.modal('hide');
 		if (changed)
 		{
-			Notification.show('#Notif_SetSpeedLimit');
+			PopupNotification.show('#Notif_SetSpeedLimit');
 		}
 		Refresher.update();
 	}
+
+	function toggleLimit()
+	{
+		var limited = Status.status.DownloadLimit > 0;
+		for (var i=0; i < Status.status.NewsServers.length; i++)
+		{
+			var server = Status.status.NewsServers[i];
+			limited = limited || !server.Active;
+		}
+
+		var defRate = Options.option('DownloadRate');
+		var rate = limited ? 0 : parseInt(defRate === '' ? 0 : defRate);
+		var servers = [];
+
+		for (var i=0; i < Status.status.NewsServers.length; i++)
+		{
+			var server = Status.status.NewsServers[i];
+			var defActive = Options.option('Server' + (i + 1) + '.Active') === 'yes';
+			var newActive = limited ? true : defActive;
+			if (server.Active != newActive)
+			{
+				servers.push([server.ID, newActive]);
+			}
+		}
+
+		saveLimit(rate, servers);
+	}
+}(jQuery));
+
+/*** FILTER MENU *********************************************************/
+
+var FilterMenu = (new function($)
+{
+	'use strict';
+
+	var $SaveFilterDialog;
+	var $SaveFilterInput;
+	var $Table_filter;
+	var ignoreClick = false;
+	var $Table_filter;
+	var tabName;
+	var items;
+	
+	this.init = function()
+	{
+		$SaveFilterDialog = $('#SaveFilterDialog');
+		$SaveFilterInput = $('#SaveFilterInput');
+
+		if (UISettings.setFocus)
+		{
+			$SaveFilterDialog.on('shown', function ()
+			{
+				$SaveFilterInput.focus();
+			});
+		}
+	}
+
+	this.setTab = function(tabname)
+	{
+		tabName = tabname;
+		$Table_filter = $('#' + tabName + 'Table_filter');
+		load();
+	}
+
+	this.redraw = function()
+	{
+		var menu = $('#FilterMenu');
+		var menuItemTemplate = $('.filter-menu-template', menu);
+		var insertPos = $('#FilterMenu_Divider', menu);
+
+		$('.filter-menu', menu).remove();
+
+		for (var i = 0; i < items.length; i++)
+		{
+			var name = items[i].name;
+			var item = menuItemTemplate.clone().removeClass('filter-menu-template').removeClass('hide').addClass('filter-menu');
+			var t = $('span', item);
+			t.text(name);
+			var a = $('a', item);
+			a.click(applyFilter);
+			a.attr('data-id', i);
+			var im = $('button', item);
+			im.click(deleteFilter);
+			im.attr('data-id', i);
+			insertPos.before(item);
+		}
+		
+		Util.show('#FilterMenu_Empty', items.length === 0);
+		
+		if (UISettings.miniTheme)
+		{
+			Frontend.alignPopupMenu('#FilterMenu');
+		}
+	}
+
+	function applyFilter()
+	{
+		if (ignoreClick)
+		{
+			ignoreClick = false;
+			return;
+		}
+		var id = parseInt($(this).attr('data-id'));
+		$Table_filter.val(items[id].filter);
+		$('#' + tabName +'Table').fasttable('applyFilter', $Table_filter.val());
+	}
+
+	function deleteFilter()
+	{
+		ignoreClick = true;
+		var id = parseInt($(this).attr('data-id'));
+		items.splice(id, 1);
+		save();
+	}
+
+	this.saveDialogClick = function()
+	{
+		if ($Table_filter.val() === '')
+		{
+			PopupNotification.show('#Notif_SaveFilterEmpty');
+			return;
+		}
+
+		var filter = $Table_filter.val();
+		var name = filter;
+
+		// reuse the name if the filter already exists
+		for (var i = 0; i < items.length; i++)
+		{
+			if (items[i].filter === filter)
+			{
+				name = items[i].name;
+				break;
+			}
+		}
+
+		$SaveFilterInput.val(name);
+		$SaveFilterDialog.modal();
+	}
+	
+	this.saveClick = function()
+	{
+		$SaveFilterDialog.modal('hide');
+
+		var name = $SaveFilterInput.val();
+		var filter = $Table_filter.val();
+
+		// rename if already exists
+		for (var i = 0; i < items.length; i++)
+		{
+			if (items[i].filter === filter)
+			{
+				items[i].name = name;
+				save();
+				return;
+			}
+		}
+		
+		// doesn't exist - add new
+		items.push({name: name, filter: filter});
+		save();
+	}
+
+	function load()
+	{
+		items = JSON.parse(UISettings.read('Filter_' + tabName, '[]'));
+	}
+
+	function save()
+	{
+		UISettings.write('Filter_' + tabName, JSON.stringify(items));
+	}
 }(jQuery));
